==> ejc-procurement-api-3.0.0-20251208.070615-84-sources.jar: com/ejianc/business/procurement/plan/vo/PlanExceptionDetailVO.java <==
package com.ejianc.business.procurement.plan.vo;

import java.util.Date;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 采购计划异常处理明细
 * 
 * @author generator
 * 
 */
public class PlanExceptionDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Date makeDate; // 编制日期
    private String billCode; // 执行计划编号
    private String employeeName; // 经办人名称
    private String memo; // 备注
    private String name; // 执行计划名称
    private Integer billState; // 单据状态
    private Integer permissionType; // 实施流程 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private Long employeeId; // 经办人
    private Long pid; // 主表主键
    private Long sourceId; // 原始执行计划单id
    private Boolean closed; // 是否终止

    public Boolean getClosed() {
        return closed;
    }

    public void setClosed(Boolean closed) {
        this.closed = closed;
    }

    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}

==> ejc-procurement-api-3.0.0-20251215.055410-119-sources.jar: com/ejianc/business/procurement/plan/vo/PlanExceptionDetailVO.java <==
package com.ejianc.business.procurement.plan.vo;

import java.util.Date;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 采购计划异常处理明细
 * 
 * @author generator
 * 
 */
public class PlanExceptionDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date makeDate; // 编制日期
    private String billCode; // 执行计划编号
    private String employeeName; // 经办人名称
    private String memo; // 备注
    private String name; // 执行计划名称
    private Integer billState; // 单据状态
    private Integer permissionType; // 实施流程 1-一级集采，2-二级集采，3-所属单位，4-项目经理部
    private Long employeeId; // 经办人
    private Long pid; // 主表主键
    private Long sourceId; // 原始执行计划单id
    private Boolean closed; // 是否终止

    public Boolean getClosed() {
        return closed;
    }

    public void setClosed(Boolean closed) {
        this.closed = closed;
    }

    public Date getMakeDate() {
        return makeDate;
    }

    public void setMakeDate(Date makeDate) {
        this.makeDate = makeDate;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Integer getPermissionType() {
        return permissionType;
    }

    public void setPermissionType(Integer permissionType) {
        this.permissionType = permissionType;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    
}
